==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp1/postgresql96_SUSE-SU-2017_2356-1_12.1.ltss.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for postgresql96 SUSE-SU-2017:2356-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP1 LTSS
# Source:      Security Announcement Parser v1.3.6
# Modified:    2017 Sep 08
#
##############################################################################
# Copyright (C) 2017 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "postgresql96"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.opensuse.org/opensuse-security-announce/2017-09/msg00013.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = True
NAME = 'postgresql96'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2017:2356-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 1 ):
		PACKAGES = {
			'libecpg6': '9.6.4-3.6.1',
			'libecpg6-debuginfo': '9.6.4-3.6.1',
			'libpq5': '9.6.4-3.6.1',
			'libpq5-32bit': '9.6.4-3.6.1',
			'libpq5-debuginfo': '9.6.4-3.6.1',
			'libpq5-debuginfo-32bit': '9.6.4-3.6.1',
			'postgresql96': '9.6.4-3.6.1',
			'postgresql96-contrib': '9.6.4-3.6.1',
			'postgresql96-contrib-debuginfo': '9.6.4-3.6.1',
			'postgresql96-debuginfo': '9.6.4-3.6.1',
			'postgresql96-debugsource': '9.6.4-3.6.1',
			'postgresql96-docs': '9.6.4-3.6.1',
			'postgresql96-libs-debugsource': '9.6.4-3.6.1',
			'postgresql96-server': '9.6.4-3.6.1',
			'postgresql96-server-debuginfo': '9.6.4-3.6.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp1/postgresql96_SUSE-SU-2020_0586-1_12.1.ltss.py <==
#!/usr/bin/python3
#
# Title:       Low Security Announcement for postgresql96 SUSE-SU-2020:0586-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP1 LTSS
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Nov 16
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "postgresql96"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-March/006573.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = True
NAME = 'postgresql96'
MAIN = ''
SEVERITY = 'Low'
TAG = 'SUSE-SU-2020:0586-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 1 ):
		PACKAGES = {
			'postgresql96': '9.6.17-3.33.1',
			'postgresql96-contrib': '9.6.17-3.33.1',
			'postgresql96-contrib-debuginfo': '9.6.17-3.33.1',
			'postgresql96-debuginfo': '9.6.17-3.33.1',
			'postgresql96-debugsource': '9.6.17-3.33.1',
			'postgresql96-docs': '9.6.17-3.33.1',
			'postgresql96-libs-debugsource': '9.6.17-3.33.1',
			'postgresql96-plperl': '9.6.17-3.33.1',
			'postgresql96-plperl-debuginfo': '9.6.17-3.33.1',
			'postgresql96-plpython': '9.6.17-3.33.1',
			'postgresql96-plpython-debuginfo': '9.6.17-3.33.1',
			'postgresql96-pltcl': '9.6.17-3.33.1',
			'postgresql96-pltcl-debuginfo': '9.6.17-3.33.1',
			'postgresql96-server': '9.6.17-3.33.1',
			'postgresql96-server-debuginfo': '9.6.17-3.33.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
